@@ -51,14 +51,19 @@ def pdf2svg(fin, fout, page_no=None):
     execute_command(cmd)
 
 
-def pdf2png(fin, fout=None, scale_to=None):
+def pdf2png(fin, fout=None, scale_to=None, page_to_convert=None):
     if fout is None:
         fout = fin[:-4] + ".png"
     fout = fout[:-4]
+
     cmd = f"pdftocairo -png -singlefile {fin} {fout}"
+    if page_to_convert is not None:
+        cmd += f" -f {page_to_convert} -l {page_to_convert}"
+
     if scale_to is not None:
         cmd += f" -scale-to {scale_to}"
     execute_command(cmd.split())
+
     return fout + ".png"
 
 
