@@ -16,11 +16,11 @@ CDIR = CDIR.replace('\\','/')
 SVG_EDIT_RELPATH = "osvgs" # files that are supposed to be edited goes here.
 SVG_TMP_RELPATH = "tmp" # various files that can be flat out deleted goes here
 SVG_TEXINCLUDE_RELPATH = "do_not_edit" # the no_fonts version and the pure (+fonts) versions goes here
-DTU_beamer_base = CDIR +"/DTU_Beamer_files"
+DTU_beamer_base = CDIR +"/data/DTU_Beamer_files"
 BLANK_PNG =DTU_beamer_base + "/blank.png"
 
 def ensure_dir(dname):
-    assert False
+    # assert False
     if not os.path.exists(dname):
         os.mkdir(dname)
 
@@ -35,7 +35,7 @@ def join_pdfs(slide_deck_pdf, outfile):
 
 def li_import(slide_deck_pdf, tex_output_path=None, num_to_take=None, force=False, svg_pfix="osvg", svg_height=743.75, svg_width=992.5,
               svg_converted_slides="svg_converted_slides.tex"):
-    assert False
+    # assert False
     '''
     svg_height and svg_width are used to scale the converted image. This is useful because otherwise the viewbox
     will fail to match the DTU template. I.e. these numbers will generally change dependent on the LaTeX template.
@@ -60,8 +60,8 @@ def li_import(slide_deck_pdf, tex_output_path=None, num_to_take=None, force=Fals
     if tex_output_path is None:
         tex_output_path = slide_deck_pdf[:-4]+"_output.tex"
 
-    output_dir = os.path.dirname(tex_output_path)
-
+    output_dir = os.path.dirname(os.path.abspath(tex_output_path))
+    print("Converting slides to", output_dir)
     # if output_dir is None:
     #     output_dir = os.path.dirname(slide_deck_pdf)
     assert(os.path.exists(output_dir))
@@ -287,7 +287,6 @@ def svg_edit_to_importable(svg_edit_file,verbose=False):
 #     inkscape:label="Layer 1"
 #     style="display:inline">
 # {{svg_end}}
-# </g></svg>
 # </jinja2>
 def add_png_background_to_svg(svg_input, png_file, svg_output=None):
     if not svg_output: svg_output = svg_input
@@ -305,8 +304,9 @@ def add_png_background_to_svg(svg_input, png_file, svg_output=None):
         mds_id = svg.find(mds)
 
     mds_dex = mds_id+len(mds)
+    svg_end = svg[mds_dex:].replace("</svg>", "</g></svg>")
 
-    data = {'png_file' : rp, 'svg_start': svg[:mds_dex],'svg_end': svg[mds_dex:]}
+    data = {'png_file' : rp, 'svg_start': svg[:mds_dex],'svg_end': svg_end}
     svg = jinjafy_comment(data, jinja_tag="jinja2")
 
     si = svg.find("<svg") + 4
@@ -319,12 +319,12 @@ def add_png_background_to_svg(svg_input, png_file, svg_output=None):
 
 
 def slidedeck_to_images(slide_deck_pdf, base_out_pattern, num_to_take=None):
-    assert False
+    # assert False
     if not os.path.exists(os.path.dirname(base_out_pattern)):
         os.mkdir(os.path.dirname(base_out_pattern))
     num_pages = num_pages_in_pdf(slide_deck_pdf)
     opat = base_out_pattern[:-4] + "_tmp.pdf"
-    opat.replace("%i", '%d')
+    opat = opat.replace("%i", '%d')
     cmd = f"pdftk {slide_deck_pdf} burst output {opat} compress"
     print("pdftk splitting into ", num_pages)
 
@@ -363,7 +363,8 @@ def slidedeck_to_images_DEFUNCT(slide_deck_pdf, base_out_pattern, num_to_take=No
     return outfiles
 
 def num_pages_in_pdf(pdf_file):
-    assert False
+    """ Count number of pages in a pdf file./ """
+    # assert False
     cmd = ['pdftk', '%s' % pdf_file, 'dump_data']
     ss = execute_command(cmd)[0].splitlines()
     s = int([s for s in ss if 'NumberOfPages' in s].pop().split()[-1])
@@ -406,13 +407,17 @@ def move_template_files(output_dir="examples/output", output_tex_file=None):
     files_to_move = ["tex_dtu_logo.pdf", "tex_dtu_compute_a_uk.pdf", "tex_dtu_frise.pdf", "dtucolours.tex",
                      "beamerthemeDTU.sty", "beamerfontthemeDTU.sty","beamercolorthemeDTU.sty",
                      "beamerinnerthemeDTU.sty", "beamerouterthemeDTU.sty", "departments.tex", "tex_compute_uk.pdf",
-                     "02450_beamer_preamble.tex",  # Deprecated.
+                     # "02450_beamer_preamble.tex",  # Deprecated.
                      'beamer_slider_preamble.tex', # The current version.
                      ]
 
     zipf = DTU_beamer_base + "/DTU_Beamer_files.zip"
     # os.path.exists(zipf)
 
+    for f in glob.glob(DTU_beamer_base + "/*"):
+        shutil.copyfile(f, str(output_dir) + "/" + os.path.basename(f))
+    return
+
     tmp = tempfile.mkdtemp()
 
     # output_dir = output_dir)
